pub struct QHM { /* private fields */ }Expand description
Quasi-Hyperbolic Momentum optimizer.
QHM interpolates between the current gradient and the momentum buffer, providing a generalization of both momentum and Nesterov acceleration. Update rule: p = p - lr * (nu * g + (1 - nu) * momentum)
Implementations
Sourceimpl QHM
impl QHM
Sourcepub fn with_defaults(learning_rate: f32, momentum: f32, nu: f32) -> Self
pub fn with_defaults(learning_rate: f32, momentum: f32, nu: f32) -> Self
Create QHM with default configuration.
Sourcepub fn get_config(&self) -> &QHMConfig
pub fn get_config(&self) -> &QHMConfig
Get the configuration.
Sourcepub fn set_config(&mut self, config: QHMConfig)
pub fn set_config(&mut self, config: QHMConfig)
Update configuration.