DeepDistributedQP

Struct DeepDistributedQP 

pub struct DeepDistributedQP { /* private fields */ }
DeepDistributedQP: Deep Learning-Aided Distributed Optimization.

DeepDistributedQP combines operator splitting methods with learned policies to efficiently solve large-scale quadratic programming problems in a distributed manner.

Implementations

Source

impl DeepDistributedQP

pub fn new( learning_rate: f32, num_consensus_nodes: usize, max_iterations: usize, tolerance: f32, ) -> Self

Creates a new DeepDistributedQP optimizer with the given configuration.

pub fn for_large_scale() -> Self

Creates DeepDistributedQP with configuration optimized for large-scale problems.

pub fn for_portfolio_optimization() -> Self

Creates DeepDistributedQP with configuration optimized for portfolio optimization.

pub fn with_config(config: DeepDistributedQPConfig) -> Self

Creates DeepDistributedQP with custom configuration.

pub fn qp_solver_stats(&self) -> HashMap<String, (usize, f32, f32, bool)>

Returns statistics about the distributed QP solver.

pub fn cumulative_speedup(&self) -> f32

Returns the cumulative speedup achieved.

pub fn distributed_memory_usage(&self) -> usize

Returns memory usage of consensus nodes and policy networks.

Source

impl DeepDistributedQP

pub fn num_workers(&self) -> usize

Get number of consensus workers/nodes

pub fn learning_rate(&self) -> f32

Get current learning rate

pub fn communication_rounds(&self) -> usize

Get estimated communication rounds

pub fn synchronization_overhead(&self) -> f32

Get synchronization overhead estimate

pub fn solve_qp( &mut self, problem_id: &str, p: &Tensor, q: &Tensor, a: Option<&Tensor>, b: Option<&Tensor>, g: Option<&Tensor>, h: Option<&Tensor>, ) -> Result<Tensor>

Solves a quadratic programming problem with explicit matrices.

pub fn set_policy_weights( &mut self, param_id: &str, weights: Vec<Tensor>, biases: Vec<Tensor>, ) -> Result<()>

Sets custom policy network weights.

pub fn train_policy( &mut self, param_id: &str, experience_data: &[(Tensor, f32)], ) -> Result<()>

Trains the policy network on collected experience.