pub struct FusedLayoutStats {
pub planned_layout_bytes: usize,
pub num_parameter_buffers: usize,
pub total_parameter_elements: usize,
pub memory_efficiency: f32,
pub kernel_fusion_config: KernelFusionConfig,
}Expand description
Statistics about the interleaved layout used by the fused CPU update.
These describe a layout plan; nothing is allocated on a device.
Fields
planned_layout_bytes: usizeTotal GPU memory used in bytes Bytes the interleaved layout plan occupies (padding included).
num_parameter_buffers: usizeNumber of parameter buffers
total_parameter_elements: usizeTotal parameter elements across all buffers
memory_efficiency: f32Memory efficiency (0.0 to 1.0)
kernel_fusion_config: KernelFusionConfigKernel fusion configuration
Implementations
Sourceimpl FusedLayoutStats
impl FusedLayoutStats
Sourcepub fn memory_bandwidth_utilization(&self, peak_bandwidth_gb_s: f32) -> f32
pub fn memory_bandwidth_utilization(&self, peak_bandwidth_gb_s: f32) -> f32
Calculates theoretical memory bandwidth utilization.
Sourcepub fn optimization_suggestions(&self) -> Vec<String>
pub fn optimization_suggestions(&self) -> Vec<String>
Suggests optimization strategies.